# Screen_CLS

<img src="https://igorman2005.github.io/images/screen_cls.jpg" alt="screen_cls">

Python script for clearing screen for any OS's: Windows, MAC, Linux

## Setup
https://pypi.org/project/screen-cls/

**pip install screen-cls**

## Example1:
```
import screen_cls

screen_cls.cls()
```

## Example2:
```
from screen_cls import *

cls()
```


### Documentation

https://best-itpro.ru/news/screen_cls/
